gradoptics.distributions.base\_distribution
=========================================

.. automodule:: gradoptics.distributions.base_distribution
   :members:
   :undoc-members:
   :show-inheritance:
